@@ -13,8 +13,12 @@ if __name__ == "__main__":
 
     if command == "download_knowledge_base":
         FILE_URL = "https://wikidatafiles.nyc3.digitaloceanspaces.com/Hosting/Hosting/SpacyEntityLinker/datafiles.tar.gz"
-        OUTPUT_TAR_FILE = os.path.abspath(os.path.dirname(__file__)) + '/../data/wikidb_filtered.tar.gz'
-        OUTPUT_DB_PATH = os.path.abspath(os.path.dirname(__file__)) + '/../data'
+
+        OUTPUT_TAR_FILE = os.path.abspath(
+            os.path.dirname(__file__)) + '/../data_spacy_entity_linker/wikidb_filtered.tar.gz'
+        OUTPUT_DB_PATH = os.path.abspath(os.path.dirname(__file__)) + '/../data_spacy_entity_linker'
+        if not os.path.exists(OUTPUT_DB_PATH):
+            os.makedirs(OUTPUT_DB_PATH)
         urllib.request.urlretrieve(FILE_URL, OUTPUT_TAR_FILE)
 
         tar = tarfile.open(OUTPUT_TAR_FILE)
